@@ -1,17 +1,15 @@
 package App::Midgen::Role::Attributes;
 
-use constant {TRUE => 1, FALSE => 0,};
-
+use v5.10;
 use Types::Standard qw( ArrayRef Bool Int Object Str);
 use Moo::Role;
-requires qw( experimental format );
+# use MooX::Types::MooseLike::Base qw(:all);
+use Data::Printer { caller_info => 1, colored => 1, };
 
 # Load time and dependencies negate execution time
 # use namespace::clean -except => 'meta';
 
-our $VERSION = '0.33_05';
-$VERSION = eval $VERSION; ## no critic
-
+our $VERSION = '0.23';
 use Carp;
 
 #######
@@ -28,7 +26,7 @@ has 'develop' => (
 sub _develop {
 	my $self = shift;
 
-	if ( $self->experimental && ( $self->format =~ m/cpanfile|metajson|dist/) ) {
+	if ( $self->experimental && $self->format eq 'cpanfile' ) {
 		return 1;
 	} else {
 		return 0;
@@ -36,13 +34,13 @@ sub _develop {
 }
 
 has 'distribution_name' => (
-	is   => 'rwp',
+	is   => 'rw',
 	isa  => Str,
 	lazy => 1,
 );
 
 has 'found_twins' => (
-	is      => 'rwp',
+	is      => 'rw',
 	isa     => Bool,
 	lazy    => 1,
 	default => sub {
@@ -50,25 +48,8 @@ has 'found_twins' => (
 	},
 );
 
-has 'meta2' => (
-	is      => 'ro',
-	isa     => Bool,
-	lazy    => 1,
-	builder => '_meta2',
-);
-
-sub _meta2 {
-	my $self = shift;
-
-	if ( $self->format =~ m/cpanfile|metajson|dist/ ) {
-		return TRUE;
-	} else {
-		return FALSE;
-	}
-}
-
 has 'numify' => (
-	is      => 'ro',
+	is      => 'rw',
 	isa     => Bool,
 	default => sub {0},
 	lazy    => 1,
@@ -81,33 +62,19 @@ has 'package_names' => (
 	lazy    => 1,
 );
 
-has 'phase_relationship' => (
-	is      => 'rwp',
-	isa     => Str,
-	lazy    => 1,
-	default => sub { },
-);
-
 has 'ppi_document' => (
-	is   => 'rwp',
+	is   => 'rw',
 	isa  => Object,
 	lazy => 1,
 );
 
 has 'xtest' => (
-	is      => 'rwp',
-	isa     => Bool,
-	lazy    => 1,
-	default => sub {
-	return FALSE;
-	},
-);
-
-has 'looking_infile' => (
-	is      => 'rwp',
+	is      => 'rw',
 	isa     => Str,
 	lazy    => 1,
-	default => sub { },
+	default => sub {
+		'test_requires';
+	},
 );
 
 no Moo::Role;
@@ -118,7 +85,7 @@ __END__
 
 =pod
 
-=encoding UTF-8
+=encoding utf8
 
 =head1 NAME
 
@@ -126,7 +93,7 @@ App::Midgen::Role::Attributes - Package Attributes used by L<App::Midgen>
 
 =head1 VERSION
 
-version: 0.33_05
+version: 0.23
 
 =head1 METHODS
 
@@ -170,7 +137,6 @@ See L<App::Midgen>
 
 =head1 LICENSE
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+See L<App::Midgen>
 
 =cut
