@@ -1,14 +1,13 @@
 package App::Midgen::Role::Options;
 
+use v5.10;
 use Types::Standard qw( Bool Int );
 use Moo::Role;
 
 # Load time and dependencies negate execution time
 # use namespace::clean -except => 'meta';
 
-our $VERSION = '0.33_05';
-$VERSION = eval $VERSION; ## no critic
-
+our $VERSION = '0.23';
 use Carp;
 
 #######
@@ -46,16 +45,7 @@ has 'experimental' => (
 has 'format' => (
 	is  => 'ro',
 	isa => sub {
-		my $format = {
-			dsl      => 1,
-			mi       => 1,
-			mb       => 1,
-			eumm     => 1,
-			dist     => 1,
-			cpanfile => 1,
-			metajson => 1,
-			infile   => 1
-		};
+		my $format = { dsl => 1, mi => 1, mb => 1, dzil => 1, dist => 1, cpanfile => 1, };
 		croak 'not a supported output format' unless defined $format->{ $_[0] };
 		return;
 	},
@@ -89,16 +79,13 @@ around [qw( debug verbose )] => sub {
 	my $self    = shift;
 	my $content = $self->$orig(@_);
 
-	if (   ( $self->quiet == 1 && $self->experimental == 1 )
-		|| ( $self->format eq 'infile' ) )
-	{
+	if ( $self->quiet == 1 && $self->experimental == 1 ) {
 		return 0;
 	} else {
 		return $content;
 	}
 };
 
-
 no Moo::Role;
 
 1;
@@ -107,7 +94,7 @@ __END__
 
 =pod
 
-=encoding UTF-8
+=encoding utf8
 
 =head1 NAME
 
@@ -115,7 +102,7 @@ App::Midgen::Role::Options - Package Options used by L<App::Midgen>
 
 =head1 VERSION
 
-version: 0.33_05
+version: 0.23
 
 =head1 METHODS
 
@@ -167,7 +154,6 @@ See L<App::Midgen>
 
 =head1 LICENSE
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+See L<App::Midgen>
 
 =cut
